@@ -12,12 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import Any
+
 from opentelemetry.exporter.otlp.proto.http.trace_exporter import OTLPSpanExporter
 from opentelemetry.sdk.trace.export import BatchSpanProcessor
 from pydantic import BaseModel, Field
 from typing_extensions import override
 
-from veadk.config import getenv
+from veadk.config import getenv, settings
 from veadk.tracing.telemetry.exporters.base_exporter import BaseExporter
 from veadk.utils.logger import get_logger
 
@@ -26,46 +28,46 @@ logger = get_logger(__name__)
 
 class TLSExporterConfig(BaseModel):
     endpoint: str = Field(
-        default_factory=lambda: getenv(
-            "OBSERVABILITY_OPENTELEMETRY_TLS_ENDPOINT",
-            "https://tls-cn-beijing.volces.com:4318/v1/traces",
-        ),
+        default_factory=lambda: settings.tls_config.otel_exporter_endpoint,
     )
     region: str = Field(
-        default_factory=lambda: getenv(
-            "OBSERVABILITY_OPENTELEMETRY_TLS_REGION",
-            "cn-beijing",
-        ),
+        default_factory=lambda: settings.tls_config.otel_exporter_region,
     )
     topic_id: str = Field(
-        default_factory=lambda: getenv("OBSERVABILITY_OPENTELEMETRY_TLS_SERVICE_NAME"),
+        default_factory=lambda: settings.tls_config.otel_exporter_topic_id,
     )
     access_key: str = Field(default_factory=lambda: getenv("VOLCENGINE_ACCESS_KEY"))
     secret_key: str = Field(default_factory=lambda: getenv("VOLCENGINE_SECRET_KEY"))
 
 
-class TLSExporter(BaseModel, BaseExporter):
+class TLSExporter(BaseExporter):
     config: TLSExporterConfig = Field(default_factory=TLSExporterConfig)
 
-    @override
-    def get_processor(self):
+    def model_post_init(self, context: Any) -> None:
+        logger.info(f"TLSExporter topic ID: {self.config.topic_id}")
+
         headers = {
             "x-tls-otel-tracetopic": self.config.topic_id,
             "x-tls-otel-ak": self.config.access_key,
             "x-tls-otel-sk": self.config.secret_key,
             "x-tls-otel-region": self.config.region,
         }
-        exporter = OTLPSpanExporter(
+        self.headers |= headers
+
+        self._exporter = OTLPSpanExporter(
             endpoint=self.config.endpoint,
             headers=headers,
             timeout=10,
         )
-        self._real_exporter = exporter
-        processor = BatchSpanProcessor(exporter)
-        return processor, None
 
-    def export(self):
-        self._real_exporter.force_flush()
-        logger.info(
-            f"TLSExporter exports data to {self.config.endpoint}, topic id: {self.config.topic_id}"
-        )
+        self.processor = BatchSpanProcessor(self._exporter)
+
+    @override
+    def export(self) -> None:
+        if self._exporter:
+            self._exporter.force_flush()
+            logger.info(
+                f"TLSExporter exports data to {self.config.endpoint}, topic id: {self.config.topic_id}"
+            )
+        else:
+            logger.warning("TLSExporter internal exporter is not initialized.")
